 /*
 * file      : src/export.c
 * project   : tm
 * with      : Gtk-2
 *
 * copyright : (C) 2012 by Claude BULIN
 *
 * TM - Edition des heures de travail / Edition of working hours
 * GNU General Public License
 * 
 * This file is part of TM.
 * 
 * TM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * TM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with TM.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
	#define gettext_noop(x) (x) 
#endif

#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib_tm/lib.h"
#endif

#include "global.h"
#include "configuser.h"
#include "callbacks.h"
#include "conv.h"
#include "win_info.h"



/*
http://groups.google.com/group/fr.comp.lang.postscript/browse_thread/thread/02c45a9323555bce/6ea3bd76a5363612
In article
<20b53f10-2209-494e-96ef-2b934820a...@26g2000hsk.googlegroups.com>,
 Ahmed Ayadi <ayadi.ahmed.e...@gmail.com> wrote:

> Je suis nouveau avec le language Postscript. J'aime bien imprimé des
> documents postscript avec des lettres avec accent comme 'é', 'à' et
> 'ç'.

Bonsoir.
En supposant l'usage de caractères sur 8 bits, il faut procéder au
recodage de la fonte.

Une fonte (Type 1, Type 3, TrueType, OpenType etc...) contient une
association entre un code numérique (code de caractère) et un dessin
vectoriel (glyphe) qui représente en général (au moins dans les langues
alphabétiques) une lettre, un chiffre, un signe de ponctuation etc...
Cette association est l'encodage. (encoding)
Cette association n'est pas fixée et peut être modifié via une
programmation Postscript adéquate. Cette programmation se nomme
'recodage' (re-encoding).
En Postscript les fontes ne sont pas tenues d'avoir un encodage
particulier,  et donc pour avoir des résultats reproductible avec
n'importe quelle fonte, le recodage est indispensable.

Pour une fonte T1 (ou Type 42, expression Postscript d'une TrueType),
l'encodage est donnée par le vecteur dont la clef est /Encoding dans le
dictionnaire de la fonte. Il faut modifier ce vecteur pour recoder la
fonte. Ce vecteur comporte 256 valeurs (indicées par le code de
caractère sur 8 bits, de 0 à 255). Chaque valeur de ce vecteur est un
nom de glyphe, identifiant le dessin qui sera effectué.

Donc pour recoder une fonte, on fait une copie du dictinnaire de fonte
où l'on assigne des valeurs différente aux éléments du vecteur
/Encoding. Les interpréteurs PS prédéfinissent des vecteurs usuels, ce
qui évite de devoir réinventer la roue. Un de ces vecteurs est
/ISOLatin1Encoding (voir Red Book annexe E)

Muni de ces explications, l'exemple du Red Book section 5.9.1 se
comprend mieux (sachant que pour des raisons d'unicité, il n'est pas
permis de cloner l'identificateur de fonte contenu sous clef /FID du
dictionnaire de fonte):

/Helvetica findfont
dup length dict begin
{ 1 index /FID ne
  {def}
  {pop pop}
  ifelse
} forall

/Encoding ISOLatin1Encoding def
currentdict
end
/Helvetica-ISOLatin1 exch definefont pop

/Helvetica-ISOLatin1 findfont 30 scalefont setfont
20 120 moveto (c cedille ç \347 ) show
20 90 moveto  (e grave è \350 ) show
20 60 moveto  (a grave à \340 ) show
showpage

François Robert
*/


/*
http://www.utf8-chartable.de/
	Table de caracteres
*/

/*
page 615 depuis:
	Manuel de reference du langage Postscript Edition: Addison-Wesley
*/
typedef struct {
	gint	car1, car2;
	gint	CarPostscript;
} TABLE_PS;

#define TOTAL_TABLE_PS 95

TABLE_PS TablePS [ TOTAL_TABLE_PS ] = {

 { 0xc2, 0xa1, 241 },	// 	¡	 INVERTED EXCLAMATION MARK
 { 0xc2, 0xa2, 242 },	// 	¢	 CENT SIGN
 { 0xc2, 0xa3, 243 },	// 	£	 POUND SIGN
 { 0xc2, 0xa4, 244 },	// 	¤	 CURRENCY SIGN
 { 0xc2, 0xa5, 245 },	// 	¥	 YEN SIGN
 { 0xc2, 0xa6, 246 },	// 	¦	 BROKEN BAR
 { 0xc2, 0xa7, 247 },	// 	§	 SECTION SIGN
 { 0xc2, 0xa8, 250 },	//	¨	 DIAERESIS
 { 0xc2, 0xa9, 251 },	//	©	 COPYRIGHT SIGN
 { 0xc2, 0xaa, 252 },	//	ª	 FEMININE ORDINAL INDICATOR
 { 0xc2, 0xab, 253 },	//	«	 LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
 { 0xc2, 0xac, 254 },	//	¬	 NOT SIGN
 { 0xc2, 0xad, 255 },	//		 SOFT HYPHEN
 { 0xc2, 0xae, 256 },	//	®	 REGISTERED SIGN
 { 0xc2, 0xaf, 257 },	//	¯	 MACRON
 { 0xc2, 0xb0, 260 },	//	°	 DEGREE SIGN
 { 0xc2, 0xb1, 261 },	//	±	 PLUS-MINUS SIGN
 { 0xc2, 0xb2, 262 },	//	²	 SUPERSCRIPT TWO
 { 0xc2, 0xb3, 263 },	//	³	 SUPERSCRIPT THREE
 { 0xc2, 0xb4, 264 },	//	´	 ACUTE ACCENT
 { 0xc2, 0xb5, 265 },	//	µ	 MICRO SIGN
 { 0xc2, 0xb6, 266 },	//	¶	 PILCROW SIGN
 { 0xc2, 0xb7, 267 },	//	·	 MIDDLE DOT
 { 0xc2, 0xb8, 270 },	//	¸	 CEDILLA
 { 0xc2, 0xb9, 271 },	//	¹	 SUPERSCRIPT ONE
 { 0xc2, 0xba, 272 },	//	º	 MASCULINE ORDINAL INDICATOR
 { 0xc2, 0xbb, 273 },	//	»	 RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
 { 0xc2, 0xbc, 274 },	//	¼	 VULGAR FRACTION ONE QUARTER
 { 0xc2, 0xbd, 275 },	//	½	 VULGAR FRACTION ONE HALF
 { 0xc2, 0xbe, 276 },	//	¾	 VULGAR FRACTION THREE QUARTERS
 { 0xc2, 0xbf, 277 },	//	¿	 INVERTED QUESTION MARK
 { 0xc3, 0x80, 300 },	//	À	 LATIN CAPITAL LETTER A WITH GRAVE
 { 0xc3, 0x81, 301 },	//	Á	 LATIN CAPITAL LETTER A WITH ACUTE
 { 0xc3, 0x82, 302 },	//	Â	 LATIN CAPITAL LETTER A WITH CIRCUMFLEX
 { 0xc3, 0x83, 303 },	//	Ã	 LATIN CAPITAL LETTER A WITH TILDE
 { 0xc3, 0x84, 304 },	//	Ä	 LATIN CAPITAL LETTER A WITH DIAERESIS
 { 0xc3, 0x85, 305 },	//	Å	 LATIN CAPITAL LETTER A WITH RING ABOVE
 { 0xc3, 0x86, 306 },	//	Æ	 LATIN CAPITAL LETTER AE
 { 0xc3, 0x87, 307 },	//	Ç	 LATIN CAPITAL LETTER C WITH CEDILLA
 { 0xc3, 0x88, 310 },	//	È	 LATIN CAPITAL LETTER E WITH GRAVE
 { 0xc3, 0x89, 311 },	//	É	 LATIN CAPITAL LETTER E WITH ACUTE
 { 0xc3, 0x8a, 312 },	//	Ê	 LATIN CAPITAL LETTER E WITH CIRCUMFLEX
 { 0xc3, 0x8b, 313 },	//	Ë	 LATIN CAPITAL LETTER E WITH DIAERESIS
 { 0xc3, 0x8c, 314 },	//	Ì	 LATIN CAPITAL LETTER I WITH GRAVE
 { 0xc3, 0x8d, 315 },	//	Í	 LATIN CAPITAL LETTER I WITH ACUTE
 { 0xc3, 0x8e, 316 },	//	Î	 LATIN CAPITAL LETTER I WITH CIRCUMFLEX
 { 0xc3, 0x8f, 317 },	//	Ï	 LATIN CAPITAL LETTER I WITH DIAERESIS
 { 0xc3, 0x90, 320 },	//	Ð	 LATIN CAPITAL LETTER ETH
 { 0xc3, 0x91, 321 },	//	Ñ	 LATIN CAPITAL LETTER N WITH TILDE
 { 0xc3, 0x92, 322 },	//	Ò	 LATIN CAPITAL LETTER O WITH GRAVE
 { 0xc3, 0x93, 323 },	//	Ó	 LATIN CAPITAL LETTER O WITH ACUTE
 { 0xc3, 0x94, 324 },	//	Ô	 LATIN CAPITAL LETTER O WITH CIRCUMFLEX
 { 0xc3, 0x95, 325 },	//	Õ	 LATIN CAPITAL LETTER O WITH TILDE
 { 0xc3, 0x96, 326 },	//	Ö	 LATIN CAPITAL LETTER O WITH DIAERESIS
 { 0xc3, 0x97, 327 },	// 	×	 MULTIPLICATION SIGN
 { 0xc3, 0x98, 330 },	//	Ø	 LATIN CAPITAL LETTER O WITH STROKE
 { 0xc3, 0x99, 331 },	//	Ù	 LATIN CAPITAL LETTER U WITH GRAVE
 { 0xc3, 0x9a, 332 },	//	Ú	 LATIN CAPITAL LETTER U WITH ACUTE
 { 0xc3, 0x9b, 333 },	//	Û	 LATIN CAPITAL LETTER U WITH CIRCUMFLEX
 { 0xc3, 0x9c, 334 },	//	Ü	 LATIN CAPITAL LETTER U WITH DIAERESIS
 { 0xc3, 0x9d, 335 },	//	Ý	 LATIN CAPITAL LETTER Y WITH ACUTE
 { 0xc3, 0x9e, 336 },	//	Þ	 LATIN CAPITAL LETTER THORN
 { 0xc3, 0x9f, 337 },	//	ß	 LATIN SMALL LETTER SHARP S
 { 0xc3, 0xa0, 340 },	//	à	 LATIN SMALL LETTER A WITH GRAVE
 { 0xc3, 0xa1, 341 },	//	á	 LATIN SMALL LETTER A WITH ACUTE
 { 0xc3, 0xa2, 342 },	//	â	 LATIN SMALL LETTER A WITH CIRCUMFLEX
 { 0xc3, 0xa3, 343 },	//	ã	 LATIN SMALL LETTER A WITH TILDE
 { 0xc3, 0xa4, 344 },	//	ä	 LATIN SMALL LETTER A WITH DIAERESIS
 { 0xc3, 0xa5, 345 },	//	å	 LATIN SMALL LETTER A WITH RING ABOVE
 { 0xc3, 0xa6, 346 },	//	æ	 LATIN SMALL LETTER AE
 { 0xc3, 0xa7, 347 },	//	ç	 LATIN SMALL LETTER C WITH CEDILLA
 { 0xc3, 0xa8, 350 },	//	è	 LATIN SMALL LETTER E WITH GRAVE
 { 0xc3, 0xa9, 351 },	//	é	 LATIN SMALL LETTER E WITH ACUTE
 { 0xc3, 0xaa, 352 },	//	ê	 LATIN SMALL LETTER E WITH CIRCUMFLEX
 { 0xc3, 0xab, 353 },	//	ë	 LATIN SMALL LETTER E WITH DIAERESIS
 { 0xc3, 0xac, 354 },	//	ì	 LATIN SMALL LETTER I WITH GRAVE
 { 0xc3, 0xad, 355 },	//	í	 LATIN SMALL LETTER I WITH ACUTE
 { 0xc3, 0xae, 356 },	//	î	 LATIN SMALL LETTER I WITH CIRCUMFLEX
 { 0xc3, 0xaf, 357 },	//	ï	 LATIN SMALL LETTER I WITH DIAERESIS
 { 0xc3, 0xb0, 360 },	//	ð	 LATIN SMALL LETTER ETH
 { 0xc3, 0xb1, 361 },	//	ñ	 LATIN SMALL LETTER N WITH TILDE
 { 0xc3, 0xb2, 362 },	//	ò	 LATIN SMALL LETTER O WITH GRAVE
 { 0xc3, 0xb3, 363 },	//	ó	 LATIN SMALL LETTER O WITH ACUTE
 { 0xc3, 0xb4, 364 },	//	ô	 LATIN SMALL LETTER O WITH CIRCUMFLEX
 { 0xc3, 0xb5, 365 },	//	õ	 LATIN SMALL LETTER O WITH TILDE
 { 0xc3, 0xb6, 366 },	//	ö	 LATIN SMALL LETTER O WITH DIAERESIS
 { 0xc3, 0xb7, 367 },	//	÷	 DIVISION SIGN
 { 0xc3, 0xb8, 370 },	//	ø	 LATIN SMALL LETTER O WITH STROKE
 { 0xc3, 0xb9, 371 },	//	ù	 LATIN SMALL LETTER U WITH GRAVE
 { 0xc3, 0xba, 372 },	//	ú	 LATIN SMALL LETTER U WITH ACUTE
 { 0xc3, 0xbb, 373 },	//	û	 LATIN SMALL LETTER U WITH CIRCUMFLEX
 { 0xc3, 0xbc, 374 },	//	ü	 LATIN SMALL LETTER U WITH DIAERESIS
 { 0xc3, 0xbd, 375 },	//	ý	 LATIN SMALL LETTER Y WITH ACUTE
 { 0xc3, 0xbe, 376 },	//	þ	 LATIN SMALL LETTER THORN
 { 0xc3, 0xbf, 377 }	//	ÿ	 LATIN SMALL LETTER Y WITH DIAERESIS

};

// 
// 
gint export_get_car_table_ps( gint car1, gint car2 )
{
	gint	cpt;
	
	for (cpt = 0; cpt < TOTAL_TABLE_PS; cpt ++) {
		if (car1 == TablePS [ cpt ] . car1 && car2 == TablePS [ cpt ] . car2) break;
	}
	if (cpt >= TOTAL_TABLE_PS) {
		return (40);	// ESPACE
	}
	
	return ( TablePS [ cpt ] . CarPostscript );
}
// 
// 
void export_fprintf( FILE *fp, gchar *buf )
{
	gchar	*Ptr = buf;
	gint	car1, car2;
	
	fprintf (fp, "(");
	while (*Ptr) {
		if (*Ptr < 0) {
			car1 = *Ptr;
			car1 &= 0xff;
			car2 = *(Ptr +1);
			car2 &= 0xff;
			fprintf (fp, "\\%03d", export_get_car_table_ps (car1, car2));
			Ptr ++;
		}
		else {
			fprintf (fp, "%c", *Ptr);
		}
		Ptr ++;
	}
	fprintf (fp, ")");
}
// 
// 
void export_file_ps( gchar *p_PathNamePS, gchar *p_month )
{
	FILE		*fp = NULL;
	GList		*ListPages = NULL;
	LINE		*Line = NULL;
	GList		*ListLines = NULL;
	LINE_OF_PAGE	*Details = NULL;
	gint		NmrPage = 1;
	
	g_print("%s\n", p_PathNamePS );
	if( NULL != (fp = fopen( p_PathNamePS, "w" ))) {
		
		page_search_posX_ps();
		
		// ENTETE
		fprintf( fp,   "%%!PS-Adobe-3.0\n");
		fprintf( fp,   "%%%%Creator: BULIN Claude - fr (http://www.xcfa.tuxfamily.org/)\n");
		fprintf( fp,   "%%%%For: ()\n");
		fprintf( fp,   "%%%%Title: Time Management, %s %d\n", p_month, VarEdit.YearEdit );
		fprintf( fp,   "%%%%CreationDate: Sat, 09 Jun 2012 16:21:38\n");
		fprintf( fp,   "%%%%Pages: %d\n", AllPages.NbrPages );
		fprintf( fp,   "%%%%BoundingBox: 0 0 596 842\n");
		fprintf( fp,   "%%%%DocumentData: \n");
		fprintf( fp,   "%%%%LanguageLevel: 3\n");
		fprintf( fp,   "%%%%EndComments\n");
		fprintf( fp,   "\n");
		fprintf( fp,   "\n");
		
		fprintf( fp,   "%%=======================================================================\n");
		fprintf( fp,   "%% /Helvetica-ISOLatin1Encodin\n");
		fprintf( fp,   "%%   Prise en compte des accents\n");
		fprintf( fp,   "%% parameter: -\n");
		fprintf( fp,   "%%   none\n");
		fprintf( fp,   "%% return: -\n");
		fprintf( fp,   "%%=======================================================================\n");
		fprintf( fp,   "/Helvetica findfont\n");
		fprintf( fp,   "dup length dict begin\n");
		fprintf( fp,   "{\n");
		fprintf( fp,   "    1 index /FID ne\n");
		fprintf( fp,   "    {def}\n");
		fprintf( fp,   "    {pop pop}\n");
		fprintf( fp,   "    ifelse\n");
		fprintf( fp,   "} forall\n");
		fprintf( fp,   "    /Encoding ISOLatin1Encoding def\n");
		fprintf( fp,   "    currentdict\n");
		fprintf( fp,   "end\n");
		fprintf( fp,   "/Helvetica-ISOLatin1Encoding exch definefont pop\n");
		fprintf( fp,   "%%=======================================================================\n");
		fprintf( fp,   "%% PrintText\n");
		fprintf( fp,   "%%   Ecriture avec prise en compte des accents\n");
		fprintf( fp,   "%% parameter: -\n");
		fprintf( fp,   "%%   (Coucou) row column PrintText\n");
		fprintf( fp,   "%% return: -\n");
		fprintf( fp,   "%%=======================================================================\n");
		fprintf( fp,   "/PrintText\n");
		fprintf( fp,   "{\n");
		fprintf( fp,   "    /columns pop\n");
		fprintf( fp,   "    /columns exch def\n");
		fprintf( fp,   "    /rows pop\n");
		fprintf( fp,   "    /rows exch def\n");
		fprintf( fp,   "    /text pop\n");
		fprintf( fp,   "    /text exch def\n");
		fprintf( fp,   "    /Helvetica-ISOLatin1Encoding findfont\n");
		fprintf( fp,   "    %d scalefont\n", (gint)VarDraw.SizeFontName );
		fprintf( fp,   "    setfont\n");
		fprintf( fp,   "    0.0 setgray\n");
		fprintf( fp,   "    rows columns moveto\n");
		fprintf( fp,   "    gsave\n");
		fprintf( fp,   "    text show\n");
		fprintf( fp,   "    grestore\n");
		fprintf( fp,   "} def\n");
		fprintf( fp,   "\n");
		fprintf( fp,   "\n");
		fprintf( fp,   "%%=======================================================================\n");
		fprintf( fp,   "%% /Helvetica-Bold-ISOLatin1Encodin\n");
		fprintf( fp,   "%%   Prise en compte des accents\n");
		fprintf( fp,   "%% parameter: -\n");
		fprintf( fp,   "%%   none\n");
		fprintf( fp,   "%% return: -\n");
		fprintf( fp,   "%%=======================================================================\n");
		fprintf( fp,   "/Helvetica-Bold findfont\n");
		fprintf( fp,   "dup length dict begin\n");
		fprintf( fp,   "{\n");
		fprintf( fp,   "    1 index /FID ne\n");
		fprintf( fp,   "    {def}\n");
		fprintf( fp,   "    {pop pop}\n");
		fprintf( fp,   "    ifelse\n");
		fprintf( fp,   "} forall\n");
		fprintf( fp,   "    /Encoding ISOLatin1Encoding def\n");
		fprintf( fp,   "    currentdict\n");
		fprintf( fp,   "end\n");
		fprintf( fp,   "/Helvetica-Bold-ISOLatin1Encoding exch definefont pop\n");
		fprintf( fp,   "%%=======================================================================\n");
		fprintf( fp,   "%% PrintTextBold\n");
		fprintf( fp,   "%%   Ecriture en gras avec prise en compte des accents\n");
		fprintf( fp,   "%% parameter: -\n");
		fprintf( fp,   "%%   (Coucou) row column PrintText\n");
		fprintf( fp,   "%% return: -\n");
		fprintf( fp,   "%%=======================================================================\n");
		fprintf( fp,   "/PrintTextBold\n");
		fprintf( fp,   "{\n");
		fprintf( fp,   "    /size pop\n");
		fprintf( fp,   "    /size exch def\n");
		fprintf( fp,   "    /columns pop\n");
		fprintf( fp,   "    /columns exch def\n");
		fprintf( fp,   "    /rows pop\n");
		fprintf( fp,   "    /rows exch def\n");
		fprintf( fp,   "    /text pop\n");
		fprintf( fp,   "    /text exch def\n");
		fprintf( fp,   "    /Helvetica-Bold-ISOLatin1Encoding findfont\n");
		// fprintf( fp,   "    %d scalefont\n", (gint)VarDraw.SizeFontName );
		fprintf( fp,   "    size scalefont\n" );
		fprintf( fp,   "    setfont\n");
		fprintf( fp,   "    0.0 setgray\n");
		fprintf( fp,   "    rows columns moveto\n");
		fprintf( fp,   "    gsave\n");
		fprintf( fp,   "    text show\n");
		fprintf( fp,   "    grestore\n");
		fprintf( fp,   "} def\n");
		fprintf( fp,   "\n");
		fprintf( fp,   "\n");
		fprintf( fp,   "%%=======================================================================\n");
		fprintf( fp,   "%% /Helvetica-ISOLatin1Encodin\n");
		fprintf( fp,   "%%   Prise en compte des accents\n");
		fprintf( fp,   "%% parameter: -\n");
		fprintf( fp,   "%%   none\n");
		fprintf( fp,   "%% return: -\n");
		fprintf( fp,   "%%=======================================================================\n");
		fprintf( fp,   "/Helvetica-Oblique findfont\n");
		fprintf( fp,   "dup length dict begin\n");
		fprintf( fp,   "{\n");
		fprintf( fp,   "    1 index /FID ne\n");
		fprintf( fp,   "    {def}\n");
		fprintf( fp,   "    {pop pop}\n");
		fprintf( fp,   "    ifelse\n");
		fprintf( fp,   "} forall\n");
		fprintf( fp,   "    /Encoding ISOLatin1Encoding def\n");
		fprintf( fp,   "    currentdict\n");
		fprintf( fp,   "end\n");
		fprintf( fp,   "/Helvetica-Oblique-ISOLatin1Encoding exch definefont pop\n");
		fprintf( fp,   "%%=======================================================================\n");
		fprintf( fp,   "%% PrintTextItalic\n");
		fprintf( fp,   "%%   Ecriture en italic avec prise en compte des accents\n");
		fprintf( fp,   "%% parameter: -\n");
		fprintf( fp,   "%%   (Coucou) row column PrintText\n");
		fprintf( fp,   "%% return: -\n");
		fprintf( fp,   "%%=======================================================================\n");
		fprintf( fp,   "/PrintTextItalic\n");
		fprintf( fp,   "{\n");
		fprintf( fp,   "    /columns pop\n");
		fprintf( fp,   "    /columns exch def\n");
		fprintf( fp,   "    /rows pop\n");
		fprintf( fp,   "    /rows exch def\n");
		fprintf( fp,   "    /text pop\n");
		fprintf( fp,   "    /text exch def\n");
		fprintf( fp,   "    /Helvetica-Oblique-ISOLatin1Encoding findfont\n");
		fprintf( fp,   "    %d scalefont\n", (gint)VarDraw.SizeFontName );
		fprintf( fp,   "    setfont\n");
		fprintf( fp,   "    0.0 setgray\n");
		fprintf( fp,   "    rows columns moveto\n");
		fprintf( fp,   "    gsave\n");
		fprintf( fp,   "    text show\n");
		fprintf( fp,   "    grestore\n");
		fprintf( fp,   "} def\n");
		fprintf( fp,   "\n");
		fprintf( fp,   "\n");
		
		ListPages = g_list_first( AllPages.Page );
		while( ListPages ) {
			if( NULL != (Line = (LINE *)ListPages->data)) {
			
				fprintf( fp,   "%%%%Page: %d %d\n", NmrPage, NmrPage );
				fprintf( fp,   "%%%%BeginPageSetup\n");
				fprintf( fp,   "%%%%PageBoundingBox: 0 0 596 842\n");
				fprintf( fp,   "%%%%EndPageSetup\n");
				fprintf( fp,   "\n");
				fprintf( fp,   "0.0 setgray\n");
				fprintf( fp,   "\n");
				ListLines = g_list_first( Line->LineDetail );
				while( ListLines ) {
					if( NULL != (Details = (LINE_OF_PAGE *)ListLines->data) ) {
							if( NOUVELLE_PAGE == Details->LineType ) {
								if( NULL != Details->Str ) {
									export_fprintf( fp, Details->Str );
									fprintf( fp,   " %d %d %d PrintTextBold\n", (gint)Details->PosXPS, (gint)Details->PosYPS, (gint)Details->SizeFont );
								}
							}
							else if( STRING == Details->LineType || STRING_PAGE == Details->LineType || STRING_COMMENT == Details->LineType) {
								if( NULL != Details->Str ) {
									export_fprintf( fp, Details->Str );
									if( FONT_WEIGHT_BOLD == Details->FontWeightType)
										fprintf( fp,   " %d %d %d PrintTextBold\n", (gint)Details->PosXPS, (gint)Details->PosYPS, (gint)Details->SizeFont );
									else if( FONT_SLANT_ITALIC == Details->FontSlantType)
										fprintf( fp,   " %d %d PrintTextItalic\n", (gint)Details->PosXPS, (gint)Details->PosYPS );
									else	fprintf( fp,   " %d %d PrintText\n", (gint)Details->PosXPS, (gint)Details->PosYPS );
								}
							}
							else if( LINE_GRAPH == Details->LineType ) {
								/*
								X Y moveto
								LEN Y lineto
								stroke
								*/
								fprintf( fp,   "\n");
								fprintf( fp,   "%d %d moveto\n", (gint)Details->PosXPS, (gint)Details->PosYPS );
								// fprintf( fp,   "%d %d lineto\n", (gint)Details->LineLen, (gint)Details->PosYPS );
								fprintf( fp,   "%d %d lineto\n", VarDraw.image_width - (gint)Details->PosXPS, (gint)Details->PosYPS );
								fprintf( fp,   "stroke\n" );
								fprintf( fp,   "\n");
							}
					}
					ListLines = g_list_next( ListLines );
				}
				fprintf( fp,   "\n");
				fprintf( fp,   "showpage\n");
				fprintf( fp,   "\n");
			}
			ListPages = g_list_next( ListPages );
			NmrPage ++;
		}
		fprintf( fp,   "%%%%Trailer\n");
		fprintf( fp,   "%%%%EOF\n");
		fprintf( fp,   "\n");
		
		
		fclose( fp );
	}
}
// 
// 
void export_file( void )
{
	gchar		*PathNamePDF = NULL;
	gchar		*PathNamePS = NULL;
	gchar		*TmpPathNamePS = NULL;
	gchar		*PathNamePNG = NULL;
	gchar		*PathNameTXT = NULL;
	gint		tab_month[] = {
				CHECKBUTTON_JANVIER, CHECKBUTTON_FEVRIER, CHECKBUTTON_MARS,
				CHECKBUTTON_AVRIL, CHECKBUTTON_MAI, CHECKBUTTON_JUIN,
				CHECKBUTTON_JUILLET, CHECKBUTTON_AOUT, CHECKBUTTON_SEPTEMBRE,
				CHECKBUTTON_OCTOBRE, CHECKBUTTON_NOVEMBRE, CHECKBUTTON_DECEMBRE };	
	gint		Cpt;
	gboolean	BoolUseConv_pdf = FALSE;
	gboolean	BoolUseConv_txt = FALSE;
	
	PRINT_FUNC_LF();
	
	// TESTS TOUS LES MOIS 
	for( Cpt = 0; Cpt <= 11; Cpt ++ ) {
		
		// LE MOIS EST IL EN SELECTION ?
		if( Config.CheckbuttonMonth & tab_month[ Cpt ] ) {
			
			// LES NOMS DES FICHIERS
			PathNamePDF   = g_strdup_printf( "%s/%s.pdf", Config.PathNameFileExport, libutils_get_str_month( Cpt ) );
			PathNamePS    = g_strdup_printf( "%s/%s.ps",  Config.PathNameFileExport, libutils_get_str_month( Cpt ) );
			TmpPathNamePS = g_strdup_printf( "/tmp/%s.ps", libutils_get_str_month( Cpt ) );
			PathNamePNG   = g_strdup_printf( "%s/%s.png", Config.PathNameFileExport, libutils_get_str_month( Cpt ) );
			PathNameTXT   = g_strdup_printf( "%s/%s.txt", Config.PathNameFileExport, libutils_get_str_month( Cpt ) );
	
			// 
			// PDF POSTSCRIPT
			// 
			if( Config.CheckExportPrint & CHECKBUTTON_PDF || Config.CheckExportPrint & CHECKBUTTON_PS ) {
				VarDraw.BoolSaveToFile  = TRUE;
				// 
				// PDF
				// 
				if( Config.CheckExportPrint & CHECKBUTTON_PDF ) {
					
					BoolUseConv_pdf = TRUE;
					
					if( TRUE == libutils_find_file( "ps2pdf" ) ) {
						// CREATE POSTSCRIPT FILE IN /tmp
						export_file_ps( TmpPathNamePS, libutils_get_str_month( Cpt ) );
						// CONV POSTSCRIPT TO PDF
						conv_with_args( "ps2pdf", TmpPathNamePS, PathNamePDF, NULL );
						// REMOVE_FILE FILE IN /tmp 
						g_unlink ( TmpPathNamePS );
					}
				}
				// 
				// POSTSCRIPT
				// 
				if( Config.CheckExportPrint & CHECKBUTTON_PS ) {
					export_file_ps( PathNamePS, libutils_get_str_month( Cpt ) );
				}
				VarDraw.BoolSaveToFile  = FALSE;
			}
	
			// 
			// PNG
			// 
			if( Config.CheckExportPrint & CHECKBUTTON_PNG ) {
				VarDraw.BoolSaveToFile  = TRUE;
				g_print("%s\n", PathNamePNG );
				// convert -transform -filter Cubic -quiet -resize 596x842 ./Juillet.ps ./Juillet.png
				VarDraw.BoolSaveToFile  = FALSE;
			}
		
			// 
			// TXT
			// 
			if( Config.CheckExportPrint & CHECKBUTTON_TXT ) {
				
				BoolUseConv_txt = TRUE;
				
				if( TRUE == libutils_find_file( "ps2txt" ) ) {
					// CREATE POSTSCRIPT FILE IN /tmp
					export_file_ps( TmpPathNamePS, libutils_get_str_month( Cpt ) );
					// CONV POSTSCRIPT TO PDF
					conv_with_args( "ps2txt", TmpPathNamePS, PathNameTXT, NULL );
					// REMOVE_FILE FILE IN /tmp 
					g_unlink ( TmpPathNamePS );
				}
			}

			g_free( PathNamePDF );		PathNamePDF     = NULL;
			g_free( PathNamePS );		PathNamePS      = NULL;
			g_free( TmpPathNamePS );	TmpPathNamePS	= NULL;
			g_free( PathNamePNG );		PathNamePNG     = NULL;
			g_free( PathNameTXT );		PathNameTXT     = NULL;
		}
	}
	
	if( TRUE == BoolUseConv_pdf || TRUE == BoolUseConv_txt ) {
		if( FALSE == libutils_find_file( "ps2pdf" ) || FALSE == libutils_find_file( "ps2txt" )) {
			wininfo_create ( WindMain,
				_("ps2pdf et ps2txt ABSENTS !"),
				_("   Veuillez installer le paquet:     "),
				  "\n",
				_("   [ ghostscript ]"),
				  "\n",
				_("   qui contient les utilitaires:"),
				  "\n",
				_("   [ ps2pdf, ps2txt ]"),
				  "\n",
				  "");
		}
	}
	draw_year();
}










